Learn R Programming

CardioCurveR (version 1.0.0)

print.boot_RRi_fit: Print method for boot_RRi_fit objects

Description

Displays a concise summary of the bootstrap RRi model parameter estimates. The printed output shows the number of bootstrap replicates and a preview of the parameter estimates from the first few replicates.

Usage

# S3 method for boot_RRi_fit
print(x, ...)

Value

A message (of class NULL) with the number of bootstrap replicates and a preview of the first 6 bootstrap samples. Additionally, returns the input object invisibly.

Arguments

x

An object of class "boot_RRi_fit".

...

Additional arguments passed to print.