Learn R Programming

CardioCurveR (version 1.0.0)

print.summary.RRi_fit: Print summary of RRi_fit objects

Description

Print summary of RRi_fit objects

Usage

# S3 method for summary.RRi_fit
print(x, ...)

Value

A message (of class NULL) with optimization method used, estimated parameters, objective value from the Hubber loss algorithm, performance statistics of the RRi model and the convergence code of the optimization method.

Arguments

x

An object of class "summary.RRi_fit".

...

Additional arguments.