Provides a detailed summary of the fitted dual-logistic model, including measures of fit such as the residual sum of squares (RSS), total sum of squares (TSS), and R-squared. The summary also includes basic information about the optimization.
# S3 method for RRi_fit
summary(object, ...)A list with the following components:
The optimization method used.
The estimated parameters from the model.
The final value of the objective (Huber loss) function.
An integer code indicating convergence (0 indicates success).
Residual sum of squares.
Total sum of squares of the observed RRi values.
Coefficient of determination.
The number of observations used.
An object of class "RRi_fit".
Additional arguments (unused).