Displays a concise summary of the bootstrap RRi model parameter estimates. The printed output shows the number of bootstrap replicates and a preview of the parameter estimates from the first few replicates.
# S3 method for boot_RRi_fit
print(x, ...)A message (of class NULL) with the number of bootstrap replicates and a preview
of the first 6 bootstrap samples. Additionally, returns the input object
invisibly.
An object of class "boot_RRi_fit".
Additional arguments passed to print.